pub struct Gen<'a> {
pub namespace: &'a str,
pub sys: bool,
pub flatten: bool,
pub cfg: bool,
pub doc: bool,
pub min_enum: bool,
pub min_inherit: bool,
pub min_xaml: bool,
}
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.